pub unsafe extern "C" fn smbc_getFunctionFstatVFS(
c: *mut SMBCCTX,
) -> smbc_fstatvfs_fnExpand description
Returns the open-file filesystem-statistics callback installed in c.
Safety
c must be a valid, initialized native context pointer.
pub unsafe extern "C" fn smbc_getFunctionFstatVFS(
c: *mut SMBCCTX,
) -> smbc_fstatvfs_fnReturns the open-file filesystem-statistics callback installed in c.
c must be a valid, initialized native context pointer.