pub unsafe extern "C" fn smbc_getFunctionNotify(
c: *mut SMBCCTX,
) -> smbc_notify_fnExpand description
Returns the directory-notification callback installed in c.
Safety
c must be a valid, initialized native context pointer.
pub unsafe extern "C" fn smbc_getFunctionNotify(
c: *mut SMBCCTX,
) -> smbc_notify_fnReturns the directory-notification callback installed in c.
c must be a valid, initialized native context pointer.