pub unsafe extern "C" fn smbc_getFunctionOpenPrintJob(
c: *mut SMBCCTX,
) -> smbc_open_print_job_fnExpand description
Returns the print-job opening callback installed in c.
Safety
c must be a valid, initialized native context pointer.
pub unsafe extern "C" fn smbc_getFunctionOpenPrintJob(
c: *mut SMBCCTX,
) -> smbc_open_print_job_fnReturns the print-job opening callback installed in c.
c must be a valid, initialized native context pointer.