pub unsafe extern "C" fn smbc_getFunctionRead(
c: *mut SMBCCTX,
) -> smbc_read_fnExpand description
Returns the file-read callback installed in c.
Safety
c must be a valid, initialized native context pointer.
pub unsafe extern "C" fn smbc_getFunctionRead(
c: *mut SMBCCTX,
) -> smbc_read_fnReturns the file-read callback installed in c.
c must be a valid, initialized native context pointer.