pub unsafe extern "C" fn smbc_getFunctionStatVFS(
c: *mut SMBCCTX,
) -> smbc_statvfs_fnExpand description
Returns the filesystem-statistics callback installed in c.
Safety
c must be a valid, initialized native context pointer.
pub unsafe extern "C" fn smbc_getFunctionStatVFS(
c: *mut SMBCCTX,
) -> smbc_statvfs_fnReturns the filesystem-statistics callback installed in c.
c must be a valid, initialized native context pointer.