pub unsafe extern "C" fn smbc_getFunctionWrite(
c: *mut SMBCCTX,
) -> smbc_write_fnExpand description
Returns the file-write callback installed in c.
Safety
c must be a valid, initialized native context pointer.
pub unsafe extern "C" fn smbc_getFunctionWrite(
c: *mut SMBCCTX,
) -> smbc_write_fnReturns the file-write callback installed in c.
c must be a valid, initialized native context pointer.